#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ShellCheck
version:              0.11.0
visibility:           public
id:                   ShellCheck-0.11.0-5YsaV5lPoLI7Dk3c5jyELp
key:                  ShellCheck-0.11.0-5YsaV5lPoLI7Dk3c5jyELp
license:              GPL-3.0-only
maintainer:           vidar@vidarholen.net
author:               Vidar Holen
homepage:             https://www.shellcheck.net/
synopsis:             Shell script analysis tool
description:
    The goals of ShellCheck are:

    * To point out and clarify typical beginner'\''s syntax issues,
    that causes a shell to give cryptic error messages.

    * To point out and clarify typical intermediate level semantic problems,
    that causes a shell to behave strangely and counter-intuitively.

    * To point out subtle caveats, corner cases and pitfalls, that may cause an
    advanced user'\''s otherwise working script to fail under future circumstances.

category:             Static Analysis
abi:                  3df07cdde1f4804b3d7325aa2e7a189c
exposed:              True
exposed-modules:
    ShellCheck.AST ShellCheck.ASTLib ShellCheck.Analytics
    ShellCheck.Analyzer ShellCheck.AnalyzerLib ShellCheck.CFG
    ShellCheck.CFGAnalysis ShellCheck.Checker
    ShellCheck.Checks.Commands ShellCheck.Checks.ControlFlow
    ShellCheck.Checks.Custom ShellCheck.Checks.ShellSupport
    ShellCheck.Data ShellCheck.Debug ShellCheck.Fixer
    ShellCheck.Formatter.CheckStyle ShellCheck.Formatter.Diff
    ShellCheck.Formatter.Format ShellCheck.Formatter.GCC
    ShellCheck.Formatter.JSON ShellCheck.Formatter.JSON1
    ShellCheck.Formatter.Quiet ShellCheck.Formatter.TTY
    ShellCheck.Interface ShellCheck.Parser ShellCheck.Prelude
    ShellCheck.Regex

hidden-modules:       Paths_ShellCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/ShellCheck-0.11.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ShellCheck-0.11.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ShellCheck-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/shellcheck
hs-libraries:         HSShellCheck-0.11.0-5YsaV5lPoLI7Dk3c5jyELp
depends:
    Diff-0.5-7tBhB2OFn0F5KrQa8PyGFR
    QuickCheck-2.15.0.1-IEDVvHXQ1Jd7OqAH4jP2Br
    aeson-2.2.2.0-D3gBId4buYWJLDjLSrsEfA array-0.5.6.0 base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    directory-1.3.8.5 fgl-5.8.3.1-GTxVq4hTXxxJG2NmmpqSEc
    filepath-1.4.300.1 mtl-2.3.1 parsec-3.1.16.1 process-1.6.19.0
    regex-tdfa-1.3.2.5-BeZN9DGCtsf7yikLZxv9p transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/shellcheck/html/ShellCheck.haddock
haddock-html:         /usr/share/doc/shellcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

